#
# spec file for package xmlgraphics-batik
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2000-2008, JPackage Project
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           xmlgraphics-batik
Version:        1.9
Release:        lp150.1.9
Summary:        Scalable Vector Graphics for Java
License:        Apache-2.0
Group:          Productivity/Graphics/Vector Editors
Url:            http://xml.apache.org/batik/
Source:         http://www.eu.apache.org/dist/xmlgraphics/batik/source/batik-src-%{version}.tar.gz
Source1:        %{name}.squiggle.script
Source2:        %{name}.svgpp.script
Source3:        %{name}.ttf2svg.script
Source4:        %{name}.rasterizer.script
Source5:        %{name}.slideshow.script
Source6:        %{name}-squiggle.desktop
Source7:        %{name}.rasterizer.policy
Patch1:         %{name}-manifests.patch
Patch2:         %{name}-policy.patch
BuildRequires:  ant
# Needed for maven conversions
BuildRequires:  javapackages-local
BuildRequires:  javapackages-tools
BuildRequires:  jython
BuildRequires:  rhino >= 1.6
BuildRequires:  unzip
BuildRequires:  xerces-j2
BuildRequires:  xml-commons-jaxp-1.3-apis >= 1.3.03
Requires:       rhino >= 1.6
Requires:       xml-commons-jaxp-1.3-apis >= 1.3.03
Obsoletes:      batik < %{version}-%{release}
Provides:       batik = %{version}-%{release}
BuildArch:      noarch

%description
Batik is a Java(tm) technology based toolkit for applications that want
to use images in the Scalable Vector Graphics (SVG) format for various
purposes, such as viewing, generation or manipulation.

%package squiggle
Summary:        Batik SVG browser
Group:          Productivity/Graphics/Vector Editors
Requires:       %{name} = %{version}-%{release}
Requires:       xerces-j2 >= 2.3
Obsoletes:      batik-squiggle < %{version}-%{release}
Provides:       batik-squiggle = %{version}-%{release}

%description squiggle
The Squiggle SVG Browser lets you view SVG file, zoom, pan and rotate
in the content and select text items in the image and much more.

%package svgpp
Summary:        Batik SVG pretty printer
Group:          Productivity/Graphics/Vector Editors
Requires:       %{name} = %{version}-%{release}
Requires:       xerces-j2 >= 2.3
Obsoletes:      batik-svgpp < %{version}-%{release}
Provides:       batik-svgpp = %{version}-%{release}

%description svgpp
The SVG Pretty Printer lets developers "pretty-up" their SVG files and
get their tabulations and other cosmetic parameters in order. It can
also be used to modify the DOCTYPE declaration on SVG files.

%package ttf2svg
Summary:        Batik SVG font converter
Group:          Productivity/Graphics/Vector Editors
Requires:       %{name} = %{version}-%{release}
Obsoletes:      batik-ttf2svg < %{version}-%{release}
Provides:       batik-ttf2svg = %{version}-%{release}

%description ttf2svg
The SVG Font Converter lets developers convert character ranges from
the True Type Font format to the SVG Font format to embed in SVG
documents. This allows SVG document to be fully self-contained be
rendered exactly the same on all systems.

%package rasterizer
Summary:        Batik SVG rasterizer
Group:          Productivity/Graphics/Vector Editors
Requires:       %{name} = %{version}-%{release}
Requires:       xerces-j2 >= 2.3
Obsoletes:      batik-rasterizer < %{version}-%{release}
Provides:       batik-rasterizer = %{version}-%{release}

%description rasterizer
The SVG Rasterizer is a utility that can convert SVG files to a raster
format. The tool can convert individual files or sets of files, making
it easy to convert entire directories of SVG files. The supported
formats are JPEG, PNG, and TIFF, however the design allows new formats
to be added easily.

%package slideshow
Summary:        Batik SVG slideshow
Group:          Productivity/Graphics/Vector Editors
Requires:       %{name} = %{version}-%{release}
Requires:       xerces-j2 >= 2.3
Obsoletes:      batik-slideshow < %{version}-%{release}
Provides:       batik-slideshow = %{version}-%{release}

%description slideshow
Batik SVG slideshow.

%package demo
Summary:        Demo for %{name}
Group:          Productivity/Graphics/Vector Editors
Requires:       %{name} = %{version}-%{release}
Obsoletes:      batik-demo < %{version}-%{release}
Provides:       batik-demo = %{version}-%{release}

%description demo
Demonstrations and samples for %{name}.

%prep
%setup -q -n batik-%{version}
%patch1 -p1
%patch2 -p1

%build
export CLASSPATH=
export OPT_JAR_LIST=:
ant -Dant.build.javac.source=1.5 -Dant.build.javac.target=1.5 all-jar jars

%install

# jars
mkdir -p %{buildroot}%{_javadir}/%{name}

# This one is empty and useless...
rm batik-%{version}/batik-%{version}.jar

for dir in batik-%{version} batik-%{version}/lib batik-%{version}/extensions; do
  pushd ${dir}
    for jar in batik-*.jar; do
      basename=`basename ${jar} .jar`
      name=`echo ${basename} | sed -e 's/batik-//'`
      cp -p ${jar} %{buildroot}%{_javadir}/%{name}/${name}.jar
    done
  popd
done

for pkg in squiggle squiggle-ext svgpp ttf2svg rasterizer rasterizer-ext slideshow; do
  ln -s %{name}/${pkg}-%{version}.jar %{buildroot}%{_javadir}/batik-${pkg}-%{version}.jar
done

mv %{buildroot}%{_javadir}/%{name}/all-%{version}.jar %{buildroot}%{_javadir}/%{name}-all-%{version}.jar
ln -s %{name}-all-%{version}.jar %{buildroot}%{_javadir}/batik-all-%{version}.jar

for dir in %{buildroot}%{_javadir} %{buildroot}%{_javadir}/%{name}; do
  pushd ${dir}
    for jar in *-%{version}*.jar; do
      ln -sf ${jar} `echo $jar| sed "s|-%{version}||g"`;
    done
  popd
done

# scripts
mkdir -p %{buildroot}%{_bindir}
cp -p %{SOURCE1} %{buildroot}%{_bindir}/%{name}-squiggle
cp -p %{SOURCE2} %{buildroot}%{_bindir}/%{name}-svgpp
cp -p %{SOURCE3} %{buildroot}%{_bindir}/%{name}-ttf2svg
cp -p %{SOURCE4} %{buildroot}%{_bindir}/%{name}-rasterizer
cp -p %{SOURCE5} %{buildroot}%{_bindir}/%{name}-slideshow

# demo
mkdir -p %{buildroot}%{_datadir}/%{name}
cp -pr contrib samples test-resources test-sources \
  %{buildroot}%{_datadir}/%{name}
ln -s %{name} %{buildroot}%{_datadir}/batik

# policy
mkdir -p %{buildroot}%{_sysconfdir}/%{name}
cp -p %{SOURCE7} %{buildroot}%{_sysconfdir}/%{name}/rasterizer.policy

%files
%defattr(0644,root,root,0755)
%doc KEYS LICENSE MAINTAIN NOTICE README
%dir %{_javadir}/%{name}
%{_javadir}/%{name}-all-%{version}.jar
%{_javadir}/%{name}-all.jar
%{_javadir}/batik-all-%{version}.jar
%{_javadir}/batik-all.jar
%{_javadir}/%{name}/anim-%{version}.jar
%{_javadir}/%{name}/anim.jar
%{_javadir}/%{name}/awt-util-%{version}.jar
%{_javadir}/%{name}/awt-util.jar
%{_javadir}/%{name}/bridge-%{version}.jar
%{_javadir}/%{name}/bridge.jar
%{_javadir}/%{name}/codec-%{version}.jar
%{_javadir}/%{name}/codec.jar
%{_javadir}/%{name}/css-%{version}.jar
%{_javadir}/%{name}/css.jar
%{_javadir}/%{name}/dom-%{version}.jar
%{_javadir}/%{name}/dom.jar
%{_javadir}/%{name}/ext-%{version}.jar
%{_javadir}/%{name}/ext.jar
%{_javadir}/%{name}/extension-%{version}.jar
%{_javadir}/%{name}/extension.jar
%{_javadir}/%{name}/gui-util-%{version}.jar
%{_javadir}/%{name}/gui-util.jar
%{_javadir}/%{name}/gvt-%{version}.jar
%{_javadir}/%{name}/gvt.jar
%{_javadir}/%{name}/parser-%{version}.jar
%{_javadir}/%{name}/parser.jar
%{_javadir}/%{name}/script-%{version}.jar
%{_javadir}/%{name}/script.jar
%{_javadir}/%{name}/svg-dom-%{version}.jar
%{_javadir}/%{name}/svg-dom.jar
%{_javadir}/%{name}/svggen-%{version}.jar
%{_javadir}/%{name}/svggen.jar
%{_javadir}/%{name}/swing-%{version}.jar
%{_javadir}/%{name}/swing.jar
%{_javadir}/%{name}/transcoder-%{version}.jar
%{_javadir}/%{name}/transcoder.jar
%{_javadir}/%{name}/util-%{version}.jar
%{_javadir}/%{name}/util.jar
%{_javadir}/%{name}/xml-%{version}.jar
%{_javadir}/%{name}/xml.jar
%dir %{_sysconfdir}/%{name}

%files squiggle
%defattr(0644,root,root,0755)
%{_javadir}/%{name}/squiggle-%{version}.jar
%{_javadir}/%{name}/squiggle.jar
%{_javadir}/%{name}/squiggle-ext-%{version}.jar
%{_javadir}/%{name}/squiggle-ext.jar
%{_javadir}/batik-squiggle-%{version}.jar
%{_javadir}/batik-squiggle.jar
%{_javadir}/batik-squiggle-ext-%{version}.jar
%{_javadir}/batik-squiggle-ext.jar
%attr(0755,root,root) %{_bindir}/%{name}-squiggle

%files svgpp
%defattr(0644,root,root,0755)
%{_javadir}/%{name}/svgpp-%{version}.jar
%{_javadir}/%{name}/svgpp.jar
%{_javadir}/batik-svgpp-%{version}.jar
%{_javadir}/batik-svgpp.jar
%attr(0755,root,root) %{_bindir}/%{name}-svgpp

%files ttf2svg
%defattr(0644,root,root,0755)
%{_javadir}/%{name}/ttf2svg-%{version}.jar
%{_javadir}/%{name}/ttf2svg.jar
%{_javadir}/batik-ttf2svg-%{version}.jar
%{_javadir}/batik-ttf2svg.jar
%attr(0755,root,root) %{_bindir}/%{name}-ttf2svg

%files rasterizer
%defattr(0644,root,root,0755)
%{_javadir}/%{name}/rasterizer-%{version}.jar
%{_javadir}/%{name}/rasterizer.jar
%{_javadir}/%{name}/rasterizer-ext-%{version}.jar
%{_javadir}/%{name}/rasterizer-ext.jar
%{_javadir}/batik-rasterizer-%{version}.jar
%{_javadir}/batik-rasterizer.jar
%{_javadir}/batik-rasterizer-ext-%{version}.jar
%{_javadir}/batik-rasterizer-ext.jar
%attr(0755,root,root) %{_bindir}/%{name}-rasterizer
%config(noreplace) %{_sysconfdir}/%{name}/rasterizer.policy

%files slideshow
%defattr(0644,root,root,0755)
%{_javadir}/%{name}/slideshow-%{version}.jar
%{_javadir}/%{name}/slideshow.jar
%{_javadir}/batik-slideshow-%{version}.jar
%{_javadir}/batik-slideshow.jar
%attr(0755,root,root) %{_bindir}/%{name}-slideshow

%files demo
%defattr(0644,root,root,0755)
%{_datadir}/%{name}
%{_datadir}/batik
%exclude %{_datadir}/%{name}/contrib/rasterizertask/build.sh
%exclude %{_datadir}/%{name}/contrib/charts/convert.sh
%attr(0755,root,root) %{_datadir}/%{name}/contrib/rasterizertask/build.sh
%attr(0755,root,root) %{_datadir}/%{name}/contrib/charts/convert.sh

%changelog
* Fri May 19 2017 tchvatal@suse.com
- Version update to batik 1.9:
  * No obvious upstream changelog
- Refresh patch xmlgraphics-batik-manifests.patch
- Refresh patch xmlgraphics-batik-policy.patch
* Fri May 19 2017 vsistek@suse.com
- Add BuildRequires: javapackages-local (for maven conversions)
* Mon Mar 20 2017 sknorr@suse.com
- Needed as a dependency for FOP 2.1 (FATE#322405)
* Fri Mar  4 2016 fvogt@suse.com
- Update to batik-1.8:
    batik-src-1.7.zip -> batik-src-1.8.tar.gz
- Update xmlgraphics-batik-manifests.patch
- Refresh xmlgraphics-batik-policy.patch
* Mon Dec  8 2014 tchvatal@suse.com
- spec-cleanify
* Fri Dec  5 2014 p.drouand@gmail.com
- Use javapackages-tools instead of java-devel
* Fri Jun 27 2014 tchvatal@suse.com
- Specify targets to build on sle11.
* Thu Sep 12 2013 tchvatal@suse.com
- Kill javadoc to remove unresolvables.
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Fri Apr  5 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Wed Nov  3 2010 mvyskocil@suse.cz
- merge with xmlgraphics-batik-1.7-5.jpp5.src.rpm
* Tue Mar 30 2010 mvyskocil@suse.cz
- enable batik-all.jar to ensure swingx (-> netbeans) build
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Mon Aug 31 2009 ro@suse.de
- fix archive compression
* Thu May 15 2008 toms@suse.de
- Fixed errors in build by correction build.xml.patch:
  Replaced target="1.5" with target="1.4"
- Cleaned up SPEC file a bit
* Wed Mar  5 2008 toms@suse.de
- Fixed BuildRequires
* Fri Feb 29 2008 toms@suse.de
- Removed from samples/tests/spec/fonts/ directory due to license issues:
  fontAltGlyph.svg, fontAltGlyph3.svg, fontChoice.svg, fontDecorations.svg,
  fontGlyphChoice.svg, fontGlyphsBoth.svg, fontGlyphsChildSVG.svg,
  fontGlyphsD.svg, fontKerning.svg, fontStyling.svg and
  samples/tests/spec/scripting/textcontent/missing-glpyh.svg
* Tue Jan 29 2008 toms@suse.de
- Added additional source and created subpackage -javadoc
* Mon Jan 28 2008 toms@suse.de
- Reorganised installation directory: Installed all jar files under
  %%{_javadir} and created link from %%{_datadir}/%%{name}
- Corrected *sh.in files
* Wed Aug 29 2007 toms@suse.de
- Removed samples/tests/spec/scripting/textcontent/missing-glpyh.svg
  due to license issues
* Tue Aug 21 2007 toms@suse.de
- Updated to version 1.7
  Removed samples/fonts directory
* Wed May 23 2007 toms@suse.de
- Corrected sh files (missing #), improved SPEC file
* Fri Mar 30 2007 toms@suse.de
- Removed samples subdirectory
* Fri Mar 30 2007 toms@suse.de
- Added unzip to BuildRequires
* Thu Mar 29 2007 toms@suse.de
- Corrected *-sh files
* Thu Mar 29 2007 toms@suse.de
- First inital version of 1.6
